<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Sans nom</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Créer</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Nouvel album</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Voulez-vous vraiment supprimer cet album ?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Ou faites glisser des photos ici</translation>
    </message>
    <message>
        <source>%1 photo(s)</source>
        <translation>%1 photo(s)</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importer tout</translation>
    </message>
    <message>
        <source>The photos will be permanently deleted after the days shown on it</source>
        <translation type="vanished">Les photos seront supprimées définitivement après les jours indiqués dessus</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importer vers  :</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Disque système</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Le disque est occupé, impossible d&apos;éjecter maintenant</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel album</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Loading photos, please wait...</source>
        <translation type="vanished">Chargement des photos, veuillez patienter...</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on it</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Enregistrer dans :</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format :</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualité :</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Sélectionner d&apos;autres dossiers</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Le nom de fichier ne peut pas être vide</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>existe déjà. Voulez-vous le remplacer ?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Lecteur</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Disque %1 vierge</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Chiffré</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Exporter des photos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Photo info</source>
        <translation>Informations sur la photo</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Suppression...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Restauration en cours...</translation>
    </message>
</context>
<context>
    <name>ImageLoadFromLocalThread</name>
    <message>
        <source>days</source>
        <translation type="vanished">jours</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>Voulez-vous vraiment supprimer cette photo de l&apos;album ?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 photos from albums?</source>
        <translation type="vanished">Voulez-vous vraiment supprimer %1 photos des albums ?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Infos de l&apos;image</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informations sur la photo</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Appareil</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albums</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel album</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation type="vanished">Vous n&apos;êtes pas autorisé à afficher l&apos;image</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Photos</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens inverse</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Renommer l&apos;album</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album &quot;%1&quot; supprimé</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Ajout réussi à &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importation réussie</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Échec de l&apos;importation</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Échec de l&apos;exportation</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Exportation réussie</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Toutes les photos</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Chronologies</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albums</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Informations sur la photo</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Quitter le plein écran/diaporama</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporter</translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="vanished">Importer</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <source>Delete photo/album</source>
        <translation type="vanished">Supprimer une photo / un album</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel album</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Import photos</source>
        <translation>Importer des photos</translation>
    </message>
    <message>
        <source>Import Photos</source>
        <translation type="vanished">Importer des photos</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importation...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Supprimer</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Date de capture</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Date de modification</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode d&apos;exposition</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programme d&apos;exposition</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Durée d&apos;exposition</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Ouverture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Longueur focale</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Ouverture maximale</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode de mesure</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance des blancs</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensation flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modèle d&apos;appareil photo</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modèle d&apos;objectif</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espace colorimétrique</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Photo name</source>
        <translation>Nom de la photo</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Disque système</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Désélectionner</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>%1 photo(s)</source>
        <translation type="vanished">%1 photo(s)</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importé le</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importer vers </translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Photos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens inverse</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importation...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Résultats de la recherche</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Lire</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>Importing photos: &apos;%1&apos;</source>
        <translation type="vanished">Importation de photos : &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Exporting photos: &apos;%1&apos;</source>
        <translation type="vanished">Exportation de photos : &apos;%1&apos;</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Taille 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajuster à la fenêtre</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens inverse</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens inverse</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informations sur la photo</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Ajouter à l&apos;album</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Supprimer de l&apos;album</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurer</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">jours</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Aucun fichier image trouvé</translation>
    </message>
    <message>
        <source>Photo not found</source>
        <translation>Photo introuvable</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Infos de l&apos;image</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Date de modification</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Type</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Taille du fichier</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Date de capture</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Ajouter à l&apos;album</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Quitter le plein écran</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Afficher la fenêtre de navigation</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Masquer la fenêtre de navigation</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotation dans le sens horaire</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotation dans le sens antihoraire</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Définir comme fond d&apos;écran</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Afficher dans le gestionnaire de fichiers</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Défavoris</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Informations sur la photo</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Supprimer de l&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nouvel album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
</context>
</TS>
